@@ -2,4 +2,4 @@ from polyfactory.factories.base import BaseFactory
 from polyfactory.factories.dataclass_factory import DataclassFactory
 from polyfactory.factories.typed_dict_factory import TypedDictFactory
 
-__all__ = ("BaseFactory", "TypedDictFactory", "DataclassFactory")
+__all__ = ("BaseFactory", "DataclassFactory", "TypedDictFactory")
