@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import copy
+import inspect
 from abc import ABC, abstractmethod
 from collections import Counter, abc, deque
 from contextlib import suppress
@@ -38,11 +39,12 @@ from typing import (
     TypedDict,
     TypeVar,
     cast,
+    overload,
 )
 from uuid import UUID
 
 from faker import Faker
-from typing_extensions import get_args, get_origin, get_original_bases
+from typing_extensions import Self, get_args, get_origin, get_original_bases
 
 from polyfactory.constants import (
     DEFAULT_RANDOM,
@@ -88,6 +90,7 @@ if TYPE_CHECKING:
 
 
 T = TypeVar("T")
+U = TypeVar("U")
 F = TypeVar("F", bound="BaseFactory[Any]")
 
 
@@ -183,10 +186,14 @@ class BaseFactory(ABC, Generic[T]):
     _factory_type_mapping: ClassVar[dict[Any, type[BaseFactory[Any]]]]
     _base_factories: ClassVar[list[type[BaseFactory[Any]]]]
 
+    _providers: ClassVar[dict[Any, Callable[[], Any]]]
+    """Mapping of type providers that apply to all factories"""
+
     # Non-public attributes
     _extra_providers: dict[Any, Callable[[], Any]] | None = None
+    """Used to copy providers from once base factory to another dynamically generated factory for a class"""
 
-    def __init_subclass__(cls, *args: Any, **kwargs: Any) -> None:  # noqa: C901
+    def __init_subclass__(cls, *args: Any, **kwargs: Any) -> None:  # noqa: C901, PLR0912
         super().__init_subclass__(*args, **kwargs)
 
         if not hasattr(BaseFactory, "_base_factories"):
@@ -195,6 +202,9 @@ class BaseFactory(ABC, Generic[T]):
         if not hasattr(BaseFactory, "_factory_type_mapping"):
             BaseFactory._factory_type_mapping = {}
 
+        if not hasattr(BaseFactory, "_providers"):
+            BaseFactory._providers = {}
+
         if cls.__min_collection_length__ > cls.__max_collection_length__:
             msg = "Minimum collection length shouldn't be greater than maximum collection length"
             raise ConfigurationException(
@@ -244,7 +254,7 @@ class BaseFactory(ABC, Generic[T]):
         return copy.deepcopy(build_context)
 
     @classmethod
-    def _infer_model_type(cls: type[F]) -> type[T] | None:
+    def _infer_model_type(cls) -> type[T] | None:
         """Return model type inferred from class declaration.
         class Foo(ModelFactory[MyModel]):  # <<< MyModel
             ...
@@ -371,7 +381,7 @@ class BaseFactory(ABC, Generic[T]):
         }
 
     @classmethod
-    def _get_or_create_factory(cls, model: type) -> type[BaseFactory[Any]]:
+    def _get_or_create_factory(cls, model: type[U]) -> type[BaseFactory[U]]:
         """Get a factory from registered factories or generate a factory dynamically.
 
         :param model: A model type.
@@ -395,8 +405,30 @@ class BaseFactory(ABC, Generic[T]):
         msg = f"unsupported model type {model.__name__}"
         raise ParameterException(msg)  # pragma: no cover
 
+    @classmethod
+    def _get_initial_variables(cls, kwargs: Any) -> tuple[dict[str, Any], dict[str, PostGenerated], BuildContext]:
+        """Prepare the given kwargs and generate initial variables for further usage.
+
+        :param kwargs: Any build kwargs.
+
+        :returns: A tuple of build results.
+
+        """
+        _build_context = cls._get_build_context(kwargs.pop("_build_context", None))
+        _build_context["seen_models"].add(cls.__model__)
+
+        result: dict[str, Any] = {**kwargs}
+        generate_post: dict[str, PostGenerated] = {}
+
+        return result, generate_post, _build_context
+
     # Public Methods
 
+    @classmethod
+    def add_provider(cls, provider_type: Any, provider_function: Callable[[], Any]) -> None:
+        """Add a provider for a custom type to be available to all factories"""
+        cls._providers[provider_type] = provider_function
+
     @classmethod
     def is_factory_type(cls, annotation: Any) -> bool:
         """Determine whether a given field is annotated with a type that is supported by a base factory.
@@ -404,7 +436,9 @@ class BaseFactory(ABC, Generic[T]):
         :param annotation: A type annotation.
         :returns: Boolean dictating whether the annotation is a factory type
         """
-        return any(factory.is_supported_type(annotation) for factory in BaseFactory._base_factories)
+        return not inspect.isabstract(annotation) and any(
+            factory.is_supported_type(annotation) for factory in BaseFactory._base_factories
+        )
 
     @classmethod
     def is_batch_factory_type(cls, annotation: Any) -> bool:
@@ -480,7 +514,7 @@ class BaseFactory(ABC, Generic[T]):
 
     @classmethod
     def get_provider_map(cls) -> dict[Any, Callable[[], Any]]:
-        """Map types to callables.
+        """Map types to callables which accept no arguments and return a random value of the given type.
 
         :notes:
             - This method is distinct to allow overriding.
@@ -530,16 +564,35 @@ class BaseFactory(ABC, Generic[T]):
             Callable: _create_generic_fn,
             abc.Callable: _create_generic_fn,
             Counter: lambda: Counter(cls.__faker__.pystr()),
+            **(cls._providers or {}),
             **(cls._extra_providers or {}),
         }
 
+    @overload
     @classmethod
     def create_factory(
-        cls: type[F],
-        model: type[T] | None = None,
+        cls,
+        model: None = None,
         bases: tuple[type[BaseFactory[Any]], ...] | None = None,
         **kwargs: Any,
-    ) -> type[F]:
+    ) -> type[Self]: ...
+
+    @overload
+    @classmethod
+    def create_factory(
+        cls,
+        model: type[U],
+        bases: tuple[type[BaseFactory[Any]], ...] | None = None,
+        **kwargs: Any,
+    ) -> type[BaseFactory[U]]: ...
+
+    @classmethod
+    def create_factory(
+        cls,
+        model: type[U] | None = None,
+        bases: tuple[type[BaseFactory[Any]], ...] | None = None,
+        **kwargs: Any,
+    ) -> type[Self | BaseFactory[U]]:
         """Generate a factory for the given type dynamically.
 
         :param model: A type to model. Defaults to current factory __model__ if any.
@@ -552,12 +605,13 @@ class BaseFactory(ABC, Generic[T]):
         """
         if model is None:
             try:
-                model = cls.__model__
+                model = cls.__model__  # pyright: ignore[reportAssignmentType]
             except AttributeError as ex:
                 msg = "A 'model' argument is required when creating a new factory from a base one"
                 raise TypeError(msg) from ex
+
         return cast(
-            "Type[F]",
+            "Type[Self]",
             type(
                 f"{model.__name__}Factory",  # pyright: ignore[reportOptionalMemberAccess]
                 (*(bases or ()), cls),
@@ -781,7 +835,8 @@ class BaseFactory(ABC, Generic[T]):
                 build_context=build_context,
             )
 
-        if provider := cls.get_provider_map().get(unwrapped_annotation):
+        provider_map = cls.get_provider_map()
+        if provider := (provider_map.get(field_meta.annotation) or provider_map.get(unwrapped_annotation)):
             return provider()
 
         if isinstance(unwrapped_annotation, TypeVar):
@@ -793,7 +848,11 @@ class BaseFactory(ABC, Generic[T]):
             with suppress(Exception):
                 return unwrapped_annotation()
 
-        msg = f"Unsupported type: {unwrapped_annotation!r}\n\nEither extend the providers map or add a factory function for this type."
+        msg = (
+            f"Unsupported type: {unwrapped_annotation!r} on field '{field_meta.name}' from class {cls.__name__}."
+            "\n\nEither use 'add_provider', extend the providers map, or add a factory function for the field on the model."
+        )
+
         raise ParameterException(
             msg,
         )
@@ -856,7 +915,10 @@ class BaseFactory(ABC, Generic[T]):
 
                 yield handle_collection_type_coverage(child_meta, origin, cls, build_context=build_context)
 
-            elif provider := cls.get_provider_map().get(unwrapped_annotation):
+            elif provider := (
+                (provider_map := cls.get_provider_map()).get(field_meta.annotation)
+                or provider_map.get(unwrapped_annotation)
+            ):
                 yield CoverageContainerCallable(provider)
 
             elif isinstance(unwrapped_annotation, TypeVar):
@@ -971,11 +1033,7 @@ class BaseFactory(ABC, Generic[T]):
         :returns: A dictionary of build results.
 
         """
-        _build_context = cls._get_build_context(kwargs.pop("_build_context", None))
-        _build_context["seen_models"].add(cls.__model__)
-
-        result: dict[str, Any] = {**kwargs}
-        generate_post: dict[str, PostGenerated] = {}
+        result, generate_post, _build_context = cls._get_initial_variables(kwargs)
 
         for field_meta in cls.get_model_fields():
             field_build_parameters = cls.extract_field_build_parameters(field_meta=field_meta, build_args=kwargs)
@@ -1025,11 +1083,7 @@ class BaseFactory(ABC, Generic[T]):
         :returns: A dictionary of build results.
 
         """
-        _build_context = cls._get_build_context(kwargs.pop("_build_context", None))
-        _build_context["seen_models"].add(cls.__model__)
-
-        result: dict[str, Any] = {**kwargs}
-        generate_post: dict[str, PostGenerated] = {}
+        result, generate_post, _build_context = cls._get_initial_variables(kwargs)
 
         for field_meta in cls.get_model_fields():
             field_build_parameters = cls.extract_field_build_parameters(field_meta=field_meta, build_args=kwargs)
@@ -1069,7 +1123,7 @@ class BaseFactory(ABC, Generic[T]):
             yield resolved
 
     @classmethod
-    def build(cls, **kwargs: Any) -> T:
+    def build(cls, *_: Any, **kwargs: Any) -> T:
         """Build an instance of the factory's __model__
 
         :param kwargs: Any kwargs. If field names are set in kwargs, their values will be used.
@@ -1093,7 +1147,7 @@ class BaseFactory(ABC, Generic[T]):
 
     @classmethod
     def coverage(cls, **kwargs: Any) -> abc.Iterator[T]:
-        """Build a batch of the factory's Meta.model will full coverage of the sub-types of the model.
+        """Build a batch of the factory's Meta.model with full coverage of the sub-types of the model.
 
         :param kwargs: Any kwargs. If field_meta names are set in kwargs, their values will be used.
 
