@@ -6,13 +6,11 @@ from datetime import timezone
 from functools import partial
 from os.path import realpath
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, ClassVar, ForwardRef, Generic, Mapping, Tuple, TypeVar, cast
+from typing import TYPE_CHECKING, Any, ClassVar, ForwardRef, Generic, Mapping, TypeVar, cast
 from uuid import NAMESPACE_DNS, uuid1, uuid3, uuid5
 
-from typing_extensions import Literal, get_args, get_origin
+from typing_extensions import Literal, get_args
 
-from polyfactory.collection_extender import CollectionExtender
-from polyfactory.constants import DEFAULT_RANDOM
 from polyfactory.exceptions import MissingDependencyException
 from polyfactory.factories.base import BaseFactory, BuildContext
 from polyfactory.factories.base import BuildContext as BaseBuildContext
@@ -25,7 +23,35 @@ from polyfactory.value_generators.primitives import create_random_bytes
 
 try:
     import pydantic
-    from pydantic import VERSION, Json
+    from pydantic import (
+        VERSION,
+        AnyHttpUrl,
+        AnyUrl,
+        ByteSize,
+        EmailStr,
+        FutureDate,
+        HttpUrl,
+        IPvAnyAddress,
+        IPvAnyInterface,
+        IPvAnyNetwork,
+        Json,
+        NameEmail,
+        NegativeFloat,
+        NegativeInt,
+        NonNegativeInt,
+        NonPositiveFloat,
+        PastDate,
+        PaymentCardNumber,
+        PositiveFloat,
+        PositiveInt,
+        SecretBytes,
+        SecretStr,
+        StrictBool,
+        StrictBytes,
+        StrictFloat,
+        StrictInt,
+        StrictStr,
+    )
     from pydantic.fields import FieldInfo
 except ImportError as e:
     msg = "pydantic is not installed"
@@ -33,22 +59,11 @@ except ImportError as e:
 
 try:
     # pydantic v1
-    from pydantic import (  # noqa: I001
-        UUID1,
-        UUID3,
-        UUID4,
-        UUID5,
-        AmqpDsn,
-        AnyHttpUrl,
-        AnyUrl,
-        DirectoryPath,
-        FilePath,
-        HttpUrl,
-        KafkaDsn,
-        PostgresDsn,
-        RedisDsn,
-    )
+    import pydantic as pydantic_v1
     from pydantic import BaseModel as BaseModelV1
+
+    # Keep this import last to prevent warnings from pydantic if pydantic v2
+    # is installed.
     from pydantic.color import Color
     from pydantic.fields import (  # type: ignore[attr-defined]
         DeferredType,  # pyright: ignore[attr-defined,reportAttributeAccessIssue]
@@ -56,10 +71,6 @@ try:
         Undefined,  # pyright: ignore[attr-defined,reportAttributeAccessIssue]
     )
 
-    # Keep this import last to prevent warnings from pydantic if pydantic v2
-    # is installed.
-    from pydantic import PyObject
-
     # prevent unbound variable warnings
     BaseModelV2 = BaseModelV1
     UndefinedV2 = Undefined
@@ -71,22 +82,7 @@ except ImportError:
     from pydantic_core import PydanticUndefined as UndefinedV2
     from pydantic_core import to_json
 
-    from pydantic.v1 import (  # v1 compat imports
-        UUID1,
-        UUID3,
-        UUID4,
-        UUID5,
-        AmqpDsn,
-        AnyHttpUrl,
-        AnyUrl,
-        DirectoryPath,
-        FilePath,
-        HttpUrl,
-        KafkaDsn,
-        PostgresDsn,
-        PyObject,
-        RedisDsn,
-    )
+    import pydantic.v1 as pydantic_v1  # type: ignore[no-redef]
     from pydantic.v1 import BaseModel as BaseModelV1  # type: ignore[assignment]
     from pydantic.v1.color import Color  # type: ignore[assignment]
     from pydantic.v1.fields import DeferredType, ModelField, Undefined
@@ -99,7 +95,9 @@ if TYPE_CHECKING:
 
     from typing_extensions import NotRequired, TypeGuard
 
-T = TypeVar("T", bound="BaseModelV1 | BaseModelV2")  # pyright: ignore[reportInvalidTypeForm]
+    from pydantic import BaseModel
+
+T = TypeVar("T", bound="BaseModel")
 
 _IS_PYDANTIC_V1 = VERSION.startswith("1")
 
@@ -126,6 +124,7 @@ class PydanticFieldMeta(FieldMeta):
         default: Any = ...,
         children: list[FieldMeta] | None = None,
         constraints: PydanticConstraints | None = None,
+        examples: list[Any] | None = None,
     ) -> None:
         super().__init__(
             name=name,
@@ -135,6 +134,7 @@ class PydanticFieldMeta(FieldMeta):
             children=children,
             constraints=constraints,
         )
+        self.examples = examples
 
     @classmethod
     def from_field_info(
@@ -142,7 +142,7 @@ class PydanticFieldMeta(FieldMeta):
         field_name: str,
         field_info: FieldInfo,
         use_alias: bool,
-        random: Random | None,
+        random: Random | None = None,
         randomize_collection_length: bool | None = None,
         min_collection_length: int | None = None,
         max_collection_length: int | None = None,
@@ -165,10 +165,11 @@ class PydanticFieldMeta(FieldMeta):
                 ("randomize_collection_length", randomize_collection_length),
                 ("min_collection_length", min_collection_length),
                 ("max_collection_length", max_collection_length),
+                ("random", random),
             ),
         )
         if callable(field_info.default_factory):
-            default_value = field_info.default_factory()
+            default_value = field_info.default_factory
         else:
             default_value = field_info.default if field_info.default is not UndefinedV2 else Null
 
@@ -191,7 +192,6 @@ class PydanticFieldMeta(FieldMeta):
                         field_name="",
                         field_info=merged_field_info,
                         use_alias=use_alias,
-                        random=random,
                     ),
                 )
         else:
@@ -203,7 +203,7 @@ class PydanticFieldMeta(FieldMeta):
                     metadata.append(m)
 
             constraints = cast(
-                PydanticConstraints,
+                "PydanticConstraints",
                 cls.parse_constraints(metadata=metadata) if metadata else {},
             )
 
@@ -214,14 +214,15 @@ class PydanticFieldMeta(FieldMeta):
             if is_json:
                 constraints["json"] = True
 
-        return PydanticFieldMeta.from_type(
+        result = PydanticFieldMeta.from_type(
             annotation=annotation,
             children=children,
             constraints=cast("Constraints", {k: v for k, v in constraints.items() if v is not None}) or None,
             default=default_value,
             name=name,
-            random=random or DEFAULT_RANDOM,
         )
+        result.examples = field_info.examples
+        return result
 
     @classmethod
     def from_model_field(  # pragma: no cover
@@ -231,7 +232,7 @@ class PydanticFieldMeta(FieldMeta):
         randomize_collection_length: bool | None = None,
         min_collection_length: int | None = None,
         max_collection_length: int | None = None,
-        random: Random = DEFAULT_RANDOM,
+        random: Random | None = None,
     ) -> PydanticFieldMeta:
         """Create an instance from a pydantic model field.
         :param model_field: A pydantic ModelField.
@@ -250,6 +251,7 @@ class PydanticFieldMeta(FieldMeta):
                 ("randomize_collection_length", randomize_collection_length),
                 ("min_collection_length", min_collection_length),
                 ("max_collection_length", max_collection_length),
+                ("random", random),
             ),
         )
 
@@ -298,19 +300,24 @@ class PydanticFieldMeta(FieldMeta):
         # pydantic v1 has constraints set for these values, but we generate them using faker
         if unwrap_optional(annotation) in (
             AnyUrl,
-            HttpUrl,
-            KafkaDsn,
-            PostgresDsn,
-            RedisDsn,
-            AmqpDsn,
             AnyHttpUrl,
+            HttpUrl,
+            pydantic_v1.AnyUrl,
+            pydantic_v1.AnyHttpUrl,
+            pydantic_v1.HttpUrl,
+            pydantic_v1.KafkaDsn,
+            pydantic_v1.PostgresDsn,
+            pydantic_v1.RedisDsn,
+            pydantic_v1.AmqpDsn,
+            pydantic_v1.EmailStr,
+            pydantic_v1.NameEmail,
         ):
             constraints = {}
 
         if model_field.field_info.const and (
             default_value is None or isinstance(default_value, (int, bool, str, bytes))
         ):
-            annotation = Literal[default_value]  # pyright: ignore  # noqa: PGH003
+            annotation = Literal[default_value]
 
         children: list[FieldMeta] = []
 
@@ -325,35 +332,23 @@ class PydanticFieldMeta(FieldMeta):
                 if model_field.key_field is not None
                 else model_field.sub_fields
             )
-            type_args = tuple(
-                (
-                    sub_field.outer_type_
-                    if isinstance(sub_field.annotation, DeferredType)
-                    else unwrap_new_type(sub_field.annotation)
-                )
-                for sub_field in fields_to_iterate
-            )
-            type_arg_to_sub_field = dict(zip(type_args, fields_to_iterate))
-            if get_origin(outer_type) in (tuple, Tuple) and get_args(outer_type)[-1] == Ellipsis:
-                # pydantic removes ellipses from Tuples in sub_fields
-                type_args += (...,)
-            extended_type_args = CollectionExtender.extend_type_args(annotation, type_args, 1)
             children.extend(
                 PydanticFieldMeta.from_model_field(
-                    model_field=type_arg_to_sub_field[arg],
+                    model_field=arg,
                     use_alias=use_alias,
-                    random=random,
                 )
-                for arg in extended_type_args
+                for arg in fields_to_iterate
             )
 
+        examples = None
+
         return PydanticFieldMeta(
             name=name,
-            random=random or DEFAULT_RANDOM,
-            annotation=annotation,
+            annotation=annotation,  # pyright: ignore[reportArgumentType]
             children=children or None,
             default=default_value,
             constraints=cast("PydanticConstraints", {k: v for k, v in constraints.items() if v is not None}) or None,
+            examples=examples,
         )
 
     if not _IS_PYDANTIC_V1:
@@ -375,6 +370,28 @@ class ModelFactory(Generic[T], BaseFactory[T]):
 
     __forward_ref_resolution_type_mapping__: ClassVar[Mapping[str, type]] = {}
     __is_base_factory__ = True
+    __use_examples__: ClassVar[bool] = False  # for backwards compatibility
+    """
+    Flag indicating whether to use a random example, if provided (Pydantic >=V2)
+
+    Example code::
+
+        class Payment(BaseModel):
+            amount: int = Field(0)
+            currency: str = Field(examples=['USD', 'EUR', 'INR'])
+
+        class PaymentFactory(ModelFactory[Payment]):
+            __use_examples__ = True
+
+    >>> payment = PaymentFactory.build()
+    >>> payment
+    Payment(amount=120, currency="EUR")
+    """
+
+    __config_keys__ = (
+        *BaseFactory.__config_keys__,
+        "__use_examples__",
+    )
 
     def __init_subclass__(cls, *args: Any, **kwargs: Any) -> None:
         super().__init_subclass__(*args, **kwargs)
@@ -411,7 +428,6 @@ class ModelFactory(Generic[T], BaseFactory[T]):
                     PydanticFieldMeta.from_model_field(
                         field,
                         use_alias=not cls.__model__.__config__.allow_population_by_field_name,  # type: ignore[attr-defined]
-                        random=cls.__random__,
                     )
                     for field in cls.__model__.__fields__.values()
                 ]
@@ -420,7 +436,6 @@ class ModelFactory(Generic[T], BaseFactory[T]):
                     PydanticFieldMeta.from_field_info(
                         field_info=field_info,
                         field_name=field_name,
-                        random=cls.__random__,
                         use_alias=not cls.__model__.model_config.get(  # pyright: ignore[reportGeneralTypeIssues]
                             "populate_by_name",
                             False,
@@ -438,7 +453,8 @@ class ModelFactory(Generic[T], BaseFactory[T]):
         field_build_parameters: Any | None = None,
         build_context: BuildContext | None = None,
     ) -> Any:
-        constraints = cast(PydanticConstraints, field_meta.constraints)
+        constraints = cast("PydanticConstraints", field_meta.constraints)
+
         if constraints.pop("json", None):
             value = cls.get_field_value(
                 field_meta, field_build_parameters=field_build_parameters, build_context=build_context
@@ -449,6 +465,34 @@ class ModelFactory(Generic[T], BaseFactory[T]):
             annotation, field_meta, field_build_parameters=field_build_parameters, build_context=build_context
         )
 
+    @classmethod
+    def get_field_value(
+        cls,
+        field_meta: FieldMeta,
+        field_build_parameters: Any | None = None,
+        build_context: BuildContext | None = None,
+    ) -> Any:
+        """Return a value from examples if exists, else random value.
+
+        :param field_meta: FieldMeta instance.
+        :param field_build_parameters: Any build parameters passed to the factory as kwarg values.
+        :param build_context: BuildContext data for current build.
+
+        :returns: An arbitrary value.
+
+        """
+        result: Any
+
+        field_meta = cast("PydanticFieldMeta", field_meta)
+
+        if cls.__use_examples__ and field_meta.examples:
+            result = cls.__random__.choice(field_meta.examples)
+        else:
+            result = super().get_field_value(
+                field_meta=field_meta, field_build_parameters=field_build_parameters, build_context=build_context
+            )
+        return result
+
     @classmethod
     def build(
         cls,
@@ -467,7 +511,8 @@ class ModelFactory(Generic[T], BaseFactory[T]):
 
         if "_build_context" not in kwargs:
             kwargs["_build_context"] = PydanticBuildContext(
-                seen_models=set(), factory_use_construct=factory_use_construct
+                seen_models=set(),
+                factory_use_construct=factory_use_construct,
             )
 
         processed_kwargs = cls.process_kwargs(**kwargs)
@@ -504,8 +549,8 @@ class ModelFactory(Generic[T], BaseFactory[T]):
         if cls._get_build_context(_build_context).get("factory_use_construct"):
             if _is_pydantic_v1_model(cls.__model__):
                 return cls.__model__.construct(**kwargs)  # type: ignore[return-value]
-            return cls.__model__.model_construct(**kwargs)  # type: ignore[return-value]
-        return cls.__model__(**kwargs)  # type: ignore[return-value]
+            return cls.__model__.model_construct(**kwargs)
+        return cls.__model__(**kwargs)
 
     @classmethod
     def coverage(cls, factory_use_construct: bool = False, **kwargs: Any) -> abc.Iterator[T]:
@@ -554,49 +599,54 @@ class ModelFactory(Generic[T], BaseFactory[T]):
     @classmethod
     def get_provider_map(cls) -> dict[Any, Callable[[], Any]]:
         mapping: dict[Any, Callable[[], Any]] = {
-            pydantic.ByteSize: cls.__faker__.pyint,
-            pydantic.PositiveInt: cls.__faker__.pyint,
-            pydantic.NegativeFloat: lambda: cls.__random__.uniform(-100, -1),
-            pydantic.NegativeInt: lambda: cls.__faker__.pyint() * -1,
-            pydantic.PositiveFloat: cls.__faker__.pyint,
-            pydantic.NonPositiveFloat: lambda: cls.__random__.uniform(-100, 0),
-            pydantic.NonNegativeInt: cls.__faker__.pyint,
-            pydantic.StrictInt: cls.__faker__.pyint,
-            pydantic.StrictBool: cls.__faker__.pybool,
-            pydantic.StrictBytes: partial(create_random_bytes, cls.__random__),
-            pydantic.StrictFloat: cls.__faker__.pyfloat,
-            pydantic.StrictStr: cls.__faker__.pystr,
-            pydantic.EmailStr: cls.__faker__.free_email,
-            pydantic.NameEmail: cls.__faker__.free_email,
-            pydantic.Json: cls.__faker__.json,
-            pydantic.PaymentCardNumber: cls.__faker__.credit_card_number,
-            pydantic.AnyUrl: cls.__faker__.url,
-            pydantic.AnyHttpUrl: cls.__faker__.url,
-            pydantic.HttpUrl: cls.__faker__.url,
-            pydantic.SecretBytes: partial(create_random_bytes, cls.__random__),
-            pydantic.SecretStr: cls.__faker__.pystr,
-            pydantic.IPvAnyAddress: cls.__faker__.ipv4,
-            pydantic.IPvAnyInterface: cls.__faker__.ipv4,
-            pydantic.IPvAnyNetwork: lambda: cls.__faker__.ipv4(network=True),
-            pydantic.PastDate: cls.__faker__.past_date,
-            pydantic.FutureDate: cls.__faker__.future_date,
+            ByteSize: cls.__faker__.pyint,
+            PositiveInt: cls.__faker__.pyint,
+            NegativeFloat: lambda: cls.__random__.uniform(-100, -1),
+            NegativeInt: lambda: cls.__faker__.pyint() * -1,
+            PositiveFloat: cls.__faker__.pyint,
+            NonPositiveFloat: lambda: cls.__random__.uniform(-100, 0),
+            NonNegativeInt: cls.__faker__.pyint,
+            StrictInt: cls.__faker__.pyint,
+            StrictBool: cls.__faker__.pybool,
+            StrictBytes: lambda: create_random_bytes(cls.__random__),
+            StrictFloat: cls.__faker__.pyfloat,
+            StrictStr: cls.__faker__.pystr,
+            EmailStr: cls.__faker__.free_email,
+            NameEmail: cls.__faker__.free_email,
+            Json: cls.__faker__.json,
+            PaymentCardNumber: cls.__faker__.credit_card_number,
+            AnyUrl: cls.__faker__.url,
+            AnyHttpUrl: cls.__faker__.url,
+            HttpUrl: cls.__faker__.url,
+            SecretBytes: lambda: create_random_bytes(cls.__random__),
+            SecretStr: cls.__faker__.pystr,
+            IPvAnyAddress: cls.__faker__.ipv4,
+            IPvAnyInterface: cls.__faker__.ipv4,
+            IPvAnyNetwork: lambda: cls.__faker__.ipv4(network=True),
+            PastDate: cls.__faker__.past_date,
+            FutureDate: cls.__faker__.future_date,
         }
 
         # v1 only values
         mapping.update(
             {
-                PyObject: lambda: "decimal.Decimal",
-                AmqpDsn: lambda: "amqps://example.com",
-                KafkaDsn: lambda: "kafka://localhost:9092",
-                PostgresDsn: lambda: "postgresql://user:secret@localhost",
-                RedisDsn: lambda: "redis://localhost:6379/0",
-                FilePath: lambda: Path(realpath(__file__)),
-                DirectoryPath: lambda: Path(realpath(__file__)).parent,
-                UUID1: uuid1,
-                UUID3: lambda: uuid3(NAMESPACE_DNS, cls.__faker__.pystr()),
-                UUID4: cls.__faker__.uuid4,
-                UUID5: lambda: uuid5(NAMESPACE_DNS, cls.__faker__.pystr()),
+                pydantic_v1.AnyUrl: cls.__faker__.url,
+                pydantic_v1.AnyHttpUrl: cls.__faker__.url,
+                pydantic_v1.HttpUrl: cls.__faker__.url,
+                pydantic_v1.PyObject: lambda: "decimal.Decimal",
+                pydantic_v1.AmqpDsn: lambda: "amqps://example.com",
+                pydantic_v1.KafkaDsn: lambda: "kafka://localhost:9092",
+                pydantic_v1.PostgresDsn: lambda: "postgresql://user@localhost",
+                pydantic_v1.RedisDsn: lambda: "redis://localhost:6379/0",
+                pydantic_v1.FilePath: lambda: Path(realpath(__file__)),
+                pydantic_v1.DirectoryPath: lambda: Path(realpath(__file__)).parent,
+                pydantic_v1.UUID1: uuid1,
+                pydantic_v1.UUID3: lambda: uuid3(NAMESPACE_DNS, cls.__faker__.pystr()),
+                pydantic_v1.UUID4: cls.__faker__.uuid4,
+                pydantic_v1.UUID5: lambda: uuid5(NAMESPACE_DNS, cls.__faker__.pystr()),
                 Color: cls.__faker__.hex_color,  # pyright: ignore[reportGeneralTypeIssues]
+                pydantic_v1.EmailStr: cls.__faker__.free_email,
+                pydantic_v1.NameEmail: cls.__faker__.free_email,
             },
         )
 
@@ -608,6 +658,14 @@ class ModelFactory(Generic[T], BaseFactory[T]):
                     pydantic.FutureDatetime: cls.__faker__.future_datetime,
                     pydantic.AwareDatetime: partial(cls.__faker__.date_time, timezone.utc),
                     pydantic.NaiveDatetime: cls.__faker__.date_time,
+                    pydantic.networks.AmqpDsn: lambda: "amqps://example.com",
+                    pydantic.networks.KafkaDsn: lambda: "kafka://localhost:9092",
+                    pydantic.networks.PostgresDsn: lambda: "postgresql://user@localhost",
+                    pydantic.networks.RedisDsn: lambda: "redis://localhost:6379/0",
+                    pydantic.networks.MongoDsn: lambda: "mongodb://mongodb0.example.com:27017",
+                    pydantic.networks.MariaDBDsn: lambda: "mariadb://example.com:3306",
+                    pydantic.networks.CockroachDsn: lambda: "cockroachdb://example.com:5432",
+                    pydantic.networks.MySQLDsn: lambda: "mysql://example.com:5432",
                 },
             )
 
