@@ -1,11 +1,11 @@
 from __future__ import annotations
 
 from datetime import date, datetime
-from typing import TYPE_CHECKING, Any, Callable, ClassVar, Generic, List, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Callable, ClassVar, Generic, List, Protocol, TypeVar, Union
 
 from typing_extensions import Annotated
 
-from polyfactory.exceptions import MissingDependencyException
+from polyfactory.exceptions import MissingDependencyException, ParameterException
 from polyfactory.factories.base import BaseFactory
 from polyfactory.field_meta import Constraints, FieldMeta
 from polyfactory.persistence import AsyncPersistenceProtocol, SyncPersistenceProtocol
@@ -15,6 +15,7 @@ try:
     from sqlalchemy import ARRAY, Column, Numeric, String, inspect, types
     from sqlalchemy.dialects import mssql, mysql, postgresql, sqlite
     from sqlalchemy.exc import NoInspectionAvailable
+    from sqlalchemy.ext.associationproxy import AssociationProxy
     from sqlalchemy.orm import InstanceState, Mapper
 except ImportError as e:
     msg = "sqlalchemy is not installed"
@@ -52,19 +53,29 @@ class SQLAASyncPersistence(AsyncPersistenceProtocol[T]):
         self.session = session
 
     async def save(self, data: T) -> T:
-        self.session.add(data)
-        await self.session.commit()
-        await self.session.refresh(data)
+        async with self.session as session:
+            session.add(data)
+            await session.commit()
+            await session.refresh(data)
         return data
 
     async def save_many(self, data: list[T]) -> list[T]:
-        self.session.add_all(data)
-        await self.session.commit()
-        for batch_item in data:
-            await self.session.refresh(batch_item)
+        async with self.session as session:
+            session.add_all(data)
+            await session.commit()
+            for batch_item in data:
+                await session.refresh(batch_item)
         return data
 
 
+_T_co = TypeVar("_T_co", covariant=True)
+
+
+class _SessionMaker(Protocol[_T_co]):
+    @staticmethod
+    def __call__() -> _T_co: ...
+
+
 class SQLAlchemyFactory(Generic[T], BaseFactory[T]):
     """Base factory for SQLAlchemy models."""
 
@@ -76,15 +87,18 @@ class SQLAlchemyFactory(Generic[T], BaseFactory[T]):
     """Configuration to consider columns with foreign keys as a field or not."""
     __set_relationships__: ClassVar[bool] = False
     """Configuration to consider relationships property as a model field or not."""
+    __set_association_proxy__: ClassVar[bool] = False
+    """Configuration to consider AssociationProxy property as a model field or not."""
 
-    __session__: ClassVar[Session | Callable[[], Session] | None] = None
-    __async_session__: ClassVar[AsyncSession | Callable[[], AsyncSession] | None] = None
+    __session__: ClassVar[Session | _SessionMaker[Session] | None] = None
+    __async_session__: ClassVar[AsyncSession | _SessionMaker[AsyncSession] | None] = None
 
     __config_keys__ = (
         *BaseFactory.__config_keys__,
         "__set_primary_key__",
         "__set_foreign_keys__",
         "__set_relationships__",
+        "__set_association_proxy__",
     )
 
     @classmethod
@@ -160,7 +174,10 @@ class SQLAlchemyFactory(Generic[T], BaseFactory[T]):
         try:
             annotation = type_engine.python_type
         except NotImplementedError:
-            annotation = type_engine.impl.python_type  # type: ignore[attr-defined]
+            if not hasattr(type_engine, "impl"):
+                msg = f"Unsupported type engine: {type_engine}.\nOverride get_sqlalchemy_types to support"
+                raise ParameterException(msg) from None
+            annotation = type_engine.impl.python_type  # pyright: ignore[reportAttributeAccessIssue]
 
         constraints: Constraints = {}
         for type_, constraint_fields in cls.get_sqlalchemy_constraints().items():
@@ -197,7 +214,6 @@ class SQLAlchemyFactory(Generic[T], BaseFactory[T]):
             FieldMeta.from_type(
                 annotation=cls.get_type_from_column(column),
                 name=name,
-                random=cls.__random__,
             )
             for name, column in table.columns.items()
             if cls.should_column_be_set(column)
@@ -210,9 +226,24 @@ class SQLAlchemyFactory(Generic[T], BaseFactory[T]):
                     FieldMeta.from_type(
                         name=name,
                         annotation=annotation,
-                        random=cls.__random__,
                     ),
                 )
+        if cls.__set_association_proxy__:
+            for name, attr in table.all_orm_descriptors.items():
+                if isinstance(attr, AssociationProxy):
+                    target_collection = table.relationships.get(attr.target_collection)
+                    if target_collection:
+                        target_class = target_collection.entity.class_
+                        target_attr = getattr(target_class, attr.value_attr)
+                        if target_attr:
+                            class_ = target_attr.entity.class_
+                            annotation = class_ if not target_collection.uselist else List[class_]  # type: ignore[valid-type]
+                            fields_meta.append(
+                                FieldMeta.from_type(
+                                    name=name,
+                                    annotation=annotation,
+                                )
+                            )
 
         return fields_meta
 
